@@ -82,45 +82,50 @@ class ProxySwitcher : public QWidget
 
 public:
 
+	GConfItem *lastUsed;
+
 	GConfItem *mode;
-	GConfItem *use_http;
+
 	GConfItem *http_port;
-	GConfItem *http_auth_pass;
-	GConfItem *http_auth_user;
 	GConfItem *http_host;
-	GConfItem *http_use_auth;
+
 	
 	GConfItem *auto_url;
 	GConfItem *ftp_port;
 	GConfItem *secure_port;
 	GConfItem *secure_host;
-	GConfItem *socks_host;
-	GConfItem *socks_port;
+
 	GConfItem *ftp_host;
 	GConfItem *rtsp_port;
 	GConfItem *rtsp_host;
-	//gconf keys for 
- 	QString GCONF_DIR_PROXY;
-	QString GCONF_DIR_HTTP_PROXY;
+
+	QVariant lastUsedNetworkName;
+	//gconf key for last used network
+	QString GCONF_KEY_DIR_CON;
+	QString GCONF_KEY_LAST_USED;
+	//gconf key for actualy used wireless key
+	QString	GCONF_KEY_WIRE_NAME;
+
+	//gconf key for wireless directory plus current name
+	QString GCONF_KEY_DIR_WIRE_NAME;
+
 	
 	//gconf proxy mode key
 	QString GCONF_KEY_PROXY_MODE;
 	
 	// http proxy keys
-	QString GCONF_KEY_PROXY_USE_HTTP;
+
 	QString GCONF_KEY_PROXY_PORT;
-	QString GCONF_KEY_PROXY_AUTH_PASS;
-	QString GCONF_KEY_PROXY_AUTH_USER;
+
 	QString GCONF_KEY_PROXY_HOST;
-	QString GCONF_KEY_PROXY_USE_AUTH;
+
 	
 	//system proxy keys
 	QString GCONF_KEY_PROXY_AUTO_URL;
 	QString GCONF_KEY_PROXY_FTP_PORT;
 	QString GCONF_KEY_PROXY_SECUR_PORT;
 	QString GCONF_KEY_PROXY_SECUR_HOST;
-	QString GCONF_KEY_PROXY_SOCKS_HOST;
-	QString GCONF_KEY_PROXY_SOCKS_PORT;
+	
 	QString GCONF_KEY_PROXY_FTP_HOST;
 	QString GCONF_KEY_PROXY_RTSP_PORT;
 	QString GCONF_KEY_PROXY_RTSP_HOST;
@@ -142,48 +147,16 @@ public:
 	proxyButton[1].load("/opt/proxyswitcher/none.png");
 	proxyButton[2].load("/opt/proxyswitcher/auto.png");
 	
-	GCONF_DIR_PROXY = "/system/proxy";
-	GCONF_DIR_HTTP_PROXY = "/system/http_proxy";
-
-	GCONF_KEY_PROXY_MODE = GCONF_DIR_PROXY + "/mode";
-
-	// http proxy keys
-	GCONF_KEY_PROXY_USE_HTTP = GCONF_DIR_HTTP_PROXY + "/use_http_proxy";
-	GCONF_KEY_PROXY_PORT = GCONF_DIR_HTTP_PROXY + "/port";
-	GCONF_KEY_PROXY_AUTH_PASS = GCONF_DIR_HTTP_PROXY + "/authentication_password";
-	GCONF_KEY_PROXY_AUTH_USER = GCONF_DIR_HTTP_PROXY + "/authentication_user";
-	GCONF_KEY_PROXY_HOST = GCONF_DIR_HTTP_PROXY + "/host";
-	GCONF_KEY_PROXY_USE_AUTH = GCONF_DIR_HTTP_PROXY + "/use_authentication";
+	//gconf key for last used network
+ 	GCONF_KEY_DIR_CON = "/system/osso/connectivity/IAP/";
+	GCONF_KEY_LAST_USED = GCONF_KEY_DIR_CON + "last_used_network";
+	lastUsed = new GConfItem(GCONF_KEY_LAST_USED,this);
+	lastUsedNetworkName = lastUsed->value();
 	
-	//system proxy keys
-	GCONF_KEY_PROXY_AUTO_URL = GCONF_DIR_PROXY + "/autoconfig_url";
-	GCONF_KEY_PROXY_FTP_PORT = GCONF_DIR_PROXY + "/ftp_port";
-	GCONF_KEY_PROXY_SECUR_PORT = GCONF_DIR_PROXY + "/secure_port";
-	GCONF_KEY_PROXY_SECUR_HOST = GCONF_DIR_PROXY + "/secure_host";
-	GCONF_KEY_PROXY_SOCKS_HOST = GCONF_DIR_PROXY + "/socks_host";
-	GCONF_KEY_PROXY_SOCKS_PORT = GCONF_DIR_PROXY + "/socks_port";
-	GCONF_KEY_PROXY_FTP_HOST = GCONF_DIR_PROXY + "/ftp_host";
-	GCONF_KEY_PROXY_RTSP_PORT = GCONF_DIR_PROXY + "/rtsp_port";
-	GCONF_KEY_PROXY_RTSP_HOST = GCONF_DIR_PROXY + "/rtsp_host";
-
-	mode = new GConfItem(GCONF_KEY_PROXY_MODE,this);
-	use_http = new GConfItem(GCONF_KEY_PROXY_USE_HTTP,this);
-	http_port = new GConfItem(GCONF_KEY_PROXY_PORT,this);
-	http_auth_pass = new GConfItem(GCONF_KEY_PROXY_AUTH_PASS,this);
-	http_auth_user = new GConfItem(GCONF_KEY_PROXY_AUTH_USER,this);
-	http_host = new GConfItem(GCONF_KEY_PROXY_HOST,this);
-	http_use_auth = new GConfItem(GCONF_KEY_PROXY_USE_AUTH,this);
 	
-	auto_url = new GConfItem(GCONF_KEY_PROXY_AUTO_URL,this);
-	ftp_port = new GConfItem(GCONF_KEY_PROXY_FTP_PORT,this);
-	secure_port = new GConfItem(GCONF_KEY_PROXY_SECUR_PORT,this);
-	secure_host = new GConfItem(GCONF_KEY_PROXY_SECUR_HOST,this);
-	socks_host = new GConfItem(GCONF_KEY_PROXY_SOCKS_HOST,this);
-	socks_port = new GConfItem(GCONF_KEY_PROXY_SOCKS_PORT,this);
-	ftp_host = new GConfItem(GCONF_KEY_PROXY_FTP_HOST,this);
 
-	rtsp_port = new GConfItem(GCONF_KEY_PROXY_RTSP_PORT,this);
-	rtsp_host = new GConfItem(GCONF_KEY_PROXY_RTSP_HOST,this);
+
+	setupGConfKeys();
 
         setAttribute(Qt::WA_TranslucentBackground);
         QVariant var = mode->value();
@@ -215,18 +188,76 @@ public:
     }
 
     void mouseReleaseEvent(QMouseEvent * event){
-     //Selected = false;
+     	
+   	buttonState = 0;
+     	QWidget::mouseReleaseEvent(event);
+     	QWidget::update();
+	}
 
-   buttonState = 0;
+    void checkSetCurrentUsedConnection(){
+		lastUsed = new GConfItem(GCONF_KEY_LAST_USED,this);
+		QVariant temp = lastUsed->value();		
+		if(lastUsedNetworkName.toString() != temp.toString()){
+		lastUsedNetworkName=temp;
+		setupGConfKeys();
+		}
+	}
 
-     QWidget::mouseReleaseEvent(event);
-     QWidget::update();
+    void setupGConfKeys(){
+		//gconf key for actualy used wireless key
+	GCONF_KEY_WIRE_NAME = GCONF_KEY_DIR_CON + lastUsedNetworkName.toString();
+	
+	// proxy mode keys
+
+	GCONF_KEY_PROXY_MODE = GCONF_KEY_WIRE_NAME + "/proxytype";
+
+	// http proxy keys
+	
+	GCONF_KEY_PROXY_PORT = GCONF_KEY_WIRE_NAME + "/proxy_http_port";
+	//GCONF_KEY_PROXY_AUTH_PASS = GCONF_KEY_WIRE_NAME + "/authentication_password";
+	//GCONF_KEY_PROXY_AUTH_USER = GCONF_KEY_WIRE_NAME + "/authentication_user";
+	GCONF_KEY_PROXY_HOST = GCONF_KEY_WIRE_NAME + "/http_proxy";
+	//GCONF_KEY_PROXY_USE_AUTH = GCONF_KEY_WIRE_NAME + "/use_authentication";
+	
+	//system proxy keys
+	GCONF_KEY_PROXY_AUTO_URL = GCONF_KEY_WIRE_NAME + "/autoconf_url";
+	GCONF_KEY_PROXY_FTP_PORT = GCONF_KEY_WIRE_NAME + "/proxy_ftp_port";
+	GCONF_KEY_PROXY_SECUR_PORT = GCONF_KEY_WIRE_NAME + "/proxy_https_port";
+	GCONF_KEY_PROXY_SECUR_HOST = GCONF_KEY_WIRE_NAME + "/proxy_https";
+	GCONF_KEY_PROXY_FTP_HOST = GCONF_KEY_WIRE_NAME + "/proxy_ftp";
+	GCONF_KEY_PROXY_RTSP_PORT = GCONF_KEY_WIRE_NAME + "/proxy_rtsp_port";
+	GCONF_KEY_PROXY_RTSP_HOST = GCONF_KEY_WIRE_NAME + "/proxy_rtsp";
+		//system proxy keys
+	GCONF_KEY_PROXY_AUTO_URL = GCONF_KEY_WIRE_NAME + "/autoconf_url";
+	GCONF_KEY_PROXY_FTP_PORT = GCONF_KEY_WIRE_NAME + "/proxy_ftp_port";
+	GCONF_KEY_PROXY_SECUR_PORT = GCONF_KEY_WIRE_NAME + "/proxy_https_port";
+	GCONF_KEY_PROXY_SECUR_HOST = GCONF_KEY_WIRE_NAME + "/proxy_https";
+	GCONF_KEY_PROXY_FTP_HOST = GCONF_KEY_WIRE_NAME + "/proxy_ftp";
+	GCONF_KEY_PROXY_RTSP_PORT = GCONF_KEY_WIRE_NAME + "/proxy_rtsp_port";
+	GCONF_KEY_PROXY_RTSP_HOST = GCONF_KEY_WIRE_NAME + "/proxy_rtsp";
+
+	mode = new GConfItem(GCONF_KEY_PROXY_MODE,this);
+	
+	http_port = new GConfItem(GCONF_KEY_PROXY_PORT,this);
+
+	http_host = new GConfItem(GCONF_KEY_PROXY_HOST,this);
+
+	
+	auto_url = new GConfItem(GCONF_KEY_PROXY_AUTO_URL,this);
+	ftp_port = new GConfItem(GCONF_KEY_PROXY_FTP_PORT,this);
+	secure_port = new GConfItem(GCONF_KEY_PROXY_SECUR_PORT,this);
+	secure_host = new GConfItem(GCONF_KEY_PROXY_SECUR_HOST,this);
+
+	ftp_host = new GConfItem(GCONF_KEY_PROXY_FTP_HOST,this);
+
+	rtsp_port = new GConfItem(GCONF_KEY_PROXY_RTSP_PORT,this);
+	rtsp_host = new GConfItem(GCONF_KEY_PROXY_RTSP_HOST,this);
 	}
 
     void mousePressEvent ( QMouseEvent * ev ) {
 
 
-
+	checkSetCurrentUsedConnection();
 	QVariant var = mode->value();
 
         QString proxyEnabled = var.toString();
@@ -292,7 +323,7 @@ public slots:
 
         	if (isOk){ 
 
-			use_http->set(isOk);
+			
 			
 			http_host->set(local_http_host);
 		}
@@ -338,7 +369,7 @@ public slots:
 		
 		QVariant local_ftp_host = ftp_host->value();
         
-		local_secure_host = QInputDialog::getText(this, tr("Ftp Host"),tr("Please enter your proxy's ftp url."),
+		local_ftp_host = QInputDialog::getText(this, tr("Ftp Host"),tr("Please enter your proxy's ftp url."),
 		QLineEdit::Normal,local_ftp_host.toString(), &isOk);
 
         	if (isOk) ftp_host->set(local_ftp_host);
